@@ -2,15 +2,12 @@
 Helper classes and functions for adapters
 """
 import datetime
-try:
-    import json  # Python 2.6+
-except ImportError:
-    import simplejson as json  # Python 2.5-
 
 from dateutil.relativedelta import relativedelta
 from dateutil.rrule import YEARLY, MONTHLY, DAILY, HOURLY, MINUTELY, SECONDLY
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
+from django.utils import simplejson as json
 from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas
 from matplotlib.dates import AutoDateFormatter
 from matplotlib.dates import AutoDateLocator
