@@ -1,13 +1,10 @@
 import itertools
 import logging
-try:
-    import json  # Python 2.6+
-except ImportError:
-    import simplejson as json  # Python 2.5-
 
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.db import models
+from django.utils import simplejson as json
 from django.utils.translation import ugettext as _
 import pkg_resources
 
@@ -156,6 +153,16 @@ class WorkspaceCollage(models.Model):
 
     @property
     def workspace_items(self):
+        """Return workspace items used by one of our snippets."""
+        # .distinct may not be used on textfields in oracle as oracle stores
+        # them as NCLOB columns...  At least, that was the problem when our
+        # 'name' field was a TextField instead of a CharField.  So I reverted
+        # this change as it didn't turn out to be the problem after all.
+        # Leaving it here in case it turns out to be a recurring problem.
+        # found = set()
+        # for snippet in self.snippets.all():
+        #     found.add(snippet.workspace_item)
+        # return list(found)
         return WorkspaceItem.objects.filter(
             workspacecollagesnippet__in=self.snippets.all()).distinct()
 
@@ -216,7 +223,7 @@ class WorkspaceCollageSnippetGroup(models.Model):
     workspace_collage = models.ForeignKey(WorkspaceCollage,
                                           related_name='snippet_groups')
     index = models.IntegerField(default=1000)  # larger = lower in the list
-    name = models.TextField(blank=True, null=True)
+    name = models.CharField(max_length=80, blank=True, null=True)
 
     # boundary value for statistics
     boundary_value = models.FloatField(blank=True, null=True)
@@ -275,7 +282,8 @@ class WorkspaceCollageSnippetGroup(models.Model):
                     end_date=end_date)
                 if 'percentile' in statistics_percentile75:
                     statistics_row.update(
-                        {'percentile_75': statistics_percentile75['percentile']})
+                        {'percentile_75':
+                             statistics_percentile75['percentile']})
 
                 # add name
                 statistics_row['name'] = snippet.name
@@ -295,7 +303,8 @@ class WorkspaceCollageSnippetGroup(models.Model):
         snippets = self.snippets.all()
 
         # Add snippet names
-        values_table.append(['datetime'] + [snippet.name for snippet in snippets])
+        values_table.append(['datetime'] +
+                            [snippet.name for snippet in snippets])
 
         # Collect all data and found_dates.
         found_dates = {}
@@ -306,12 +315,14 @@ class WorkspaceCollageSnippetGroup(models.Model):
 
         for snippet in snippets:
             values = snippet.workspace_item.adapter.values(
-                identifier=snippet.identifier, start_date=start_date, end_date=end_date)
+                identifier=snippet.identifier, start_date=start_date,
+                end_date=end_date)
             snippet_values[snippet.id] = {}
             # Translate list into dict with dates.
             for row in values:
                 snippet_values[snippet.id][row['datetime']] = row
-            found_dates.update(snippet_values[snippet.id])  # the value doesn't matter
+            found_dates.update(snippet_values[snippet.id])
+            # ^^^ The value doesn't matter.
 
         found_dates_sorted = found_dates.keys()
         found_dates_sorted.sort()
@@ -346,7 +357,7 @@ class WorkspaceCollageSnippetGroup(models.Model):
                     'value': self.boundary_value,
                     'style': {'linewidth': 3,
                               'linestyle': '--',
-                              'color': 'green'}
+                              'color': 'green'},
                     }, ]
         return result
 
@@ -489,10 +500,14 @@ class Legend(models.Model):
                 fraction = float(step) / (self.steps - 1)
             except ZeroDivisionError:
                 fraction = 0
-            alpha = self.min_color.a * (1 - fraction) + self.max_color.a * fraction
-            red = self.min_color.r * (1 - fraction) + self.max_color.r * fraction
-            green = self.min_color.g * (1 - fraction) + self.max_color.g * fraction
-            blue = self.min_color.b * (1 - fraction) + self.max_color.b * fraction
+            alpha = (self.min_color.a * (1 - fraction) +
+                     self.max_color.a * fraction)
+            red = (self.min_color.r * (1 - fraction) +
+                   self.max_color.r * fraction)
+            green = (self.min_color.g * (1 - fraction) +
+                     self.max_color.g * fraction)
+            blue = (self.min_color.b * (1 - fraction) +
+                    self.max_color.b * fraction)
             color = Color(a=alpha, r=red, g=green, b=blue)
 
             low_value = self.min_value + step * value_per_step
@@ -500,6 +515,6 @@ class Legend(models.Model):
             result.append({
                     'color': color,
                     'low_value': low_value,
-                    'high_value': high_value
+                    'high_value': high_value,
                     })
         return result
