@@ -1,8 +1,5 @@
 from django import template
-try:
-    import json  # Python 2.6+
-except ImportError:
-    import simplejson as json  # Python 2.5-
+from django.utils import simplejson as json
 
 from lizard_map.daterange import current_start_end_dates
 from lizard_map.models import Workspace
