@@ -1,18 +1,15 @@
 import StringIO
-try:
-    import json  # Python 2.6+
-except ImportError:
-    import simplejson as json  # Python 2.5-
 
-import mapnik
-import Image
-import csv
 from django.db.models import Max
 from django.http import HttpResponse
-from django.template import RequestContext
 from django.shortcuts import get_object_or_404
 from django.shortcuts import render_to_response
+from django.template import RequestContext
+from django.utils import simplejson as json
 from django.views.decorators.cache import never_cache
+import Image
+import csv
+import mapnik
 
 from lizard_map import coordinates
 from lizard_map.adapter import parse_identifier_json
@@ -176,7 +173,8 @@ def snippet_group_image(request, snippet_group_id, legend=True):
     for identifier in identifiers:
         if not 'layout' in identifier:
             identifier['layout'] = {}
-        identifier['layout']['aggregation_period'] = snippet_group.aggregation_period
+        identifier['layout'][
+            'aggregation_period'] = snippet_group.aggregation_period
 
     # Add legend option ('layout' is always present).
     if legend:
@@ -469,7 +467,8 @@ def workspace_item_image(request, workspace_item_id):
     identifier_list
     """
     identifier_json_list = request.GET.getlist('identifier')
-    identifier_list = [json.loads(identifier_json) for identifier_json in identifier_json_list]
+    identifier_list = [json.loads(identifier_json) for identifier_json in
+                       identifier_json_list]
 
     width = request.GET.get('width')
     height = request.GET.get('height')
@@ -571,6 +570,33 @@ def wms(request, workspace_id):
     return response
 
 
+def search_name(request):
+    """Searche for objects near GET x,y,radius then return name,"""
+    workspace_manager = WorkspaceManager(request)
+    workspace_collections = workspace_manager.load_or_create()
+
+    # xy params from the GET request.
+    google_x = float(request.GET.get('x'))
+    google_y = float(request.GET.get('y'))
+    google_radius = float(request.GET.get('radius'))
+
+    found = []
+    for workspace_collection in workspace_collections.values():
+        for workspace in workspace_collection:
+            for workspace_item in workspace.workspace_items.filter(
+                visible=True):
+                search_results = workspace_item.adapter.search(
+                    google_x, google_y, radius=google_radius)
+                found += search_results
+    if found:
+        # ``found`` is a list of dicts {'distance': ..., 'timeserie': ...}.
+        found.sort(key=lambda item: item['distance'])
+        result = {}
+        result['name'] = found[0].name
+        print found[0].name
+        return HttpResponse(simplejson.dumps(result))
+
+
 def search_coordinates(request):
     """searches for objects near GET x,y,radius returns json_popup
     of results"""
@@ -626,11 +652,13 @@ def clickinfo(request, workspace_id):
 Export
 """
 
+
 def export_snippet_group_csv(request, snippet_group_id):
     """
     Creates a table with each location as column. Each row is a datetime.
     """
-    snippet_group = WorkspaceCollageSnippetGroup.objects.get(pk=snippet_group_id)
+    snippet_group = WorkspaceCollageSnippetGroup.objects.get(
+        pk=snippet_group_id)
     start_date, end_date = current_start_end_dates(request)
     table = snippet_group.values_table(start_date, end_date)
 
